@@ -9,7 +9,7 @@ html_theme = "furo"
 # Link dates and other references in the changelog
 extensions += ['rst.linker']
 link_files = {
-    '../CHANGES.rst': dict(
+    '../NEWS.rst': dict(
         using=dict(GH='https://github.com'),
         replace=[
             dict(
@@ -40,6 +40,7 @@ nitpick_ignore = [
 extensions += ['sphinx.ext.intersphinx']
 intersphinx_mapping = {
     'python': ('https://docs.python.org/3', None),
+    'jaraco.functools': ('https://jaracofunctools.readthedocs.io/en/latest', None),
 }
 
 # Preserve authored syntax for defaults
